        IF (SLIP_INC)
        ELSE
SLIP_INC        SET     1
;**
;**     $Filename: slip.inc
;**     $Release: 1
;**     $Revision: 1
;**     $Date: 10/11/1998
;**
;**     
;**
;**     Coded by Joachim Elen
;**

;----------------------------------------------------------
;
;       SLIP Specific MACRO definition
;
;----------------------------------------------------------

JPB     MACRO   pbit,label
        jnb     pbit,label
        ENDM

JNPB    MACRO   pbit,label
        jb      pbit,label
        ENDM

PBSET   MACRO   pbit
        clr     pbit
        ENDM

PBCLR   MACRO   pbit
        setb    pbit
        ENDM

PBCPL   MACRO   pbit
        cpl     pbit
        ENDM

PBMOV   MACRO   dpbit,spbit
        mov     C,spbit
        mov     dpbit,C
        ENDM

;----------------------------------------------------------
;
;       Constants
;
;----------------------------------------------------------

;------ SLIP Frame Escape sequences

FEND            EQU 0C0h        ;Frame END
FESC            EQU 0DBh        ;Frame ESCape
TFEND           EQU 0DCh        ;Transpose Frame END
TFESC           EQU 0DDh        ;Transpose Frame ESCape


;------ Modem result codes

RC_OK           EQU 0
RC_CONNECT      EQU 1
RC_RING         EQU 2
RC_NOCARRIER    EQU 3
RC_ERROR        EQU 4
RC_C1200        EQU 5
RC_NOTONE       EQU 6
RC_BUSY         EQU 7
RC_NOANSWER     EQU 8
RC_C2400        EQU 10
RC_C4800        EQU 11
RC_C9600        EQU 12
RC_C14400       EQU 13
RC_C19200       EQU 19
RC_C21600       EQU 21
RC_C24000       EQU 24
RC_C26400       EQU 26
RC_C28800       EQU 28
RC_SYSTEMERROR  EQU 30
RC_VOID         EQU 255

;----------------------------------------------------------
;
;       External DATA memory partitioning
;
;----------------------------------------------------------
       XSTRUCTURE 0000h
        XSTRUCT AtBuffer,ATB_SIZEOF,00100h      ;AT commandbuffer
        XSTRUCT FrameBuf,FRB_SIZEOF,00100h      ;incoming frame filter
        XSTRUCT TestBuffer,TST_SIZEOF,00100h    ;testbuffer
        XSTRUCT CallBuffer,CALL_SIZEOF,00100h   ;Callsign buffer
        XSTRUCT RxBuffer,RXB_SIZEOF,03000h      ;RX buffer
        XSTRUCT TxBuffer,TXB_SIZEOF,08000h      ;TX buffer
        XSTRUCT TiBuffer,TIB_SIZEOF,03000h      ;TI buffer

HostCall       EQU     FrameBuf+0
ServCall       EQU     FrameBuf+16
InHeader       EQU     FrameBuf+32
OutHeader      EQU     FrameBuf+128



;----------------------------------------------------------
;
;       Port pin assignments
;
;----------------------------------------------------------

;------ Baycom modem status

DCD             BIT P4.6
PTT             BIT P4.7

;------ TNC status LEDs

LED_PUTGSC      BIT P4.0
LED_GETLSC      BIT P4.1
LED_GETGSC      BIT P4.2
LED_PUTLSC      BIT P4.3
LED_REJECT      BIT P4.4
LED_VALID       BIT P4.4
LED_ONLINE      BIT P4.5

;----------------------------------------------------------
;
;       On-Chip flag assignments
;
;----------------------------------------------------------

        BITSTRUCT 000h

;--- SLIP flags

        BITDEF  SF_GETTYP       ;reading KISS-frame from host
        BITDEF  SF_CFRAME       ;command-frame
        BITDEF  SF_DFRAME       ;data-frame
        BITDEF  SF_FESC         ;Frame-ESCape mode is enabled
        BITDEF  SF_CFPARAM      ;Next byte is command frame parameter


;--- TX flags

        BITDEF  TX_BUSY         ;TX/GSC busy
        BITDEF  TX_TAIL         ;TXTail active

        BITDEF  TIDONE          ;PutLSC is inactive if set

;--- AT CLI flags

        BITDEF  AT_ECHO         ;command echo enabled
        BITDEF  AT_RESULTCODES  ;resultcodes enabled
        BITDEF  AT_VERBOSE      ;verbose result codes
        BITDEF  AT_NOERRORS     ;ignore error messages
        BITDEF  AT_BUSY         ;command line is being processed
        BITDEF  AT_GLBUFFERING  ;AT chars are being buffered
        BITDEF  AT_GLGOTA       ;'A' char for AT or A/ is received
        BITDEF  AT_GLGOTCR      ;CR,LF processing activated
        BITDEF  AT_GLNOTIDLE    ;set when AT_IDLE is false
        BITDEF  AT_GLIDLE       ;set when no chars for >1 sec.

;--- Data link flags

        BITDEF  DL_CONNECT
        BITDEF  DL_FLOWOFF

;--- misc flags

        BITDEF  LED_ALT4



;----------------------------------------------------------
;
;       On-Chip byte definitions
;
;----------------------------------------------------------


        STRUCTURE 10            ;new data structure

;--- S registers, byte addressable

        UBYTE   at_index        ;offset of at data
        UBYTE   at_indexindex   ;offset counted from index
        UBYTE   at_item         ;current entry in at command list
        UBYTE   at_itemindex    ;offset in string of current entry

        UBYTE   at_glesccnt     ;number of escape characters received
        UBYTE   at_glescstr     ;type of escape string 0=none,1=+++,2=ATH
        UBYTE   at_cspeed       ;connection speed notation

        UBYTE   at_idletimer    ;if over 16, AT_IDLE is set.

        UBYTE   at_s0           ;auto answer ring number
        UBYTE   at_s1           ;ring count
        UBYTE   at_s2           ;escape code char (+)
        UBYTE   at_s3           ;carriage return char (CR)
        UBYTE   at_s4           ;line feed char (LF)
        UBYTE   at_s5           ;backspace char
        UBYTE   at_s6           ;wait time before blind dial
        UBYTE   at_s7           ;wait time for carrier
        UBYTE   at_s8           ;pause time for carrier
        UBYTE   at_s9           ;carrier detect response time
        UBYTE   at_s10          ;carrier lost to hang up delay
                    
;--- Physical Layer variables

        UBYTE   ph_randomize    ;persistance randomizer
        UBYTE   ph_command
        UBYTE   ph_txdelay
        UBYTE   ph_persist
        UBYTE   ph_slottime
        UBYTE   ph_txtail
        UBYTE   ph_fullduplex
        UBYTE   ph_valid

        UWORD   ph_legalframes
        UWORD   ph_errorframes
        UWORD   ph_validframes
        UWORD   ph_totalframes

;--- RX Variables

        APTR    rx_writeframe   ;GetGSC framepointer
        APTR    rx_writedata    ;GetGSC datapointer
        APTR    rx_readframe    ;PutLSC framepointer
        APTR    rx_readdata     ;PutLSC datapointer
        UWORD   rx_framelen     ;actual RX framelength
        UWORD   rx_allocated    ;RXBuffer allocated memory
        UBYTE   rx_framecount   ;framecounter

;--- TX Variables

        APTR    tx_writeframe   ;GetLSC framepointer
        APTR    tx_writedata    ;GetLSC datapointer
        APTR    tx_readframe    ;PutGSC framepointer
        APTR    tx_readdata     ;PutGSC datapointer
        UWORD   tx_framelen     ;actual TX framelength
        UWORD   tx_allocated    ;TXBuffer allocated memory
        UBYTE   tx_framecount   ;framecounter
        UWORD   tx_dmaframelen  ;actual TX framelength for DMA

;--- TI Variables

        APTR    ti_writedata    ;offset of ti_write position
        APTR    ti_readdata     ;offset of ti_read position
        UWORD   ti_allocated    ;number of unsent bytes in buffer

;--- Outframe header

        UBYTE   ofh_sizeof
        UBYTE   ofh_control
        UBYTE   ofh_pid

;--- Inframe header
        
        UBYTE   ifh_sizeof
        UBYTE   ifh_control
        UBYTE   ifh_pid

;--- SLIP Protocol variables

        UBYTE   slip_randomize  ;persistance randomizer
        UBYTE   slip_hardware
        UBYTE   slip_txdelay
        UBYTE   slip_persist
        UBYTE   slip_slottime
        UBYTE   slip_txtail
        UBYTE   slip_fullduplex

;--- Debug variables

        UBYTE   dbg_atoffset

        ENDIF   ; SLIP_INC





















